*****************************************************************************************
* FILE NAME:     SASOUT21_LLCP.SAS                                                      *
* DESCRIPTION:   THIS PROGRAM CONVERTS A STATES ASCII DATAFILE OF COMPLETES LOCATED AT  *
*                <DATAIN> FILEREF, INTO A SAS DATABASE STORED AT <DATAOUT> LIBREF       *
* REFERENCES:                                                                           *
* INPUT       DATAIN           FILEREF OF ASCII DATAFILE OF COMPLETES                   *
* FORMATS     FORMATS.SAS7BCAT      SAS FORMATS DATABASE                                *
* OUTPUT      DATAOUT.SASDATA  SAS DATABASE VERSION OF ASCII DATA AS SPECIFIED IN       *
*                              <DATAIN> FILEREF                                         *
* UPDATED - 06/01/2022                                                                  *
*****************************************************************************************;
********************************
* Clear Output and Log Windows *
********************************;
DM OUTPUT 'clear' continue;
DM LOG    'clear' continue;
**********************************
* DEFINE SAS ENVIRONMENT OPTIONS *
**********************************;
OPTIONS PAGENO=1 NOFMTERR;
***************************************
* CLEAR EXISTING TITLES AND FOOTNOTES *
***************************************;
TITLE ;
FOOTNOTE ;
RUN ;
******************************************************************
* INSTRUCTIONS:                                                  *
* SPECIFY PATH OF WHERE ASCII DATAFILE IS STORED                 *
* SPECIFY PATH OF WHERE SAS DATASET IS TO BE STORED              *
* SPECIFY PATH OF WHERE SAS FORMAT LIBRARY IS STORED             *
* SPECIFY PATH OF WHERE THE FORMAT ASSIGNMET STATEMENT IS STORED *
******************************************************************;

*FILENAME DATAIN '<PATH OF INPUT STATE ASCII DATAFILE OF COMPLETES>' LRECL = 2072 ;
*****************************************************************************
* EXAMPLE:                                                                  *
*       FILENAME DATAIN 'C:\BRFSS\2021\LLCP2021.ASC' LRECL = 2072           *
* NOTE: MAKE SURE THE ASTERISK IS REMOVED BEFORE THE WORD FILENAME AND      *
*       MAKE SURE THAT THE GREATER THAN AND LESS THAN SIGNS < > ARE REMOVED *
*       FROM THE FILENAME STATEMENT                                         *
*****************************************************************************;

*LIBNAME DATAOUT V7 '<PATH OF PERMANENTLY STORED SAS DATASET VERSION OF DATAIN FILEREF>'  ;
*****************************************************************************
* EXAMPLE:                                                                  *
*          LIBNAME DATAOUT 'C:\'                                            *
*          A SAS DATABASE WILL BE STORED AT C:\SASDATA.sas7bdat             *
* NOTE: MAKE SURE THE ASTERISK IS REMOVED BEFORE THE WORD LIBNAME AND       *
*       MAKE SURE THAT THE GREATER THAN AND LESS THAN SIGNS < > ARE REMOVED *
*       FROM THE LIBNAME STATEMENT                                          *
*****************************************************************************;

*LIBNAME LIBRARY '<PATH OF STORED SAS FORMAT21.SAS7BCAT>' ;
*****************************************************************************
* EXAMPLE:                                                                  *
*          LIBNAME LIBRARY 'C:\'                                            *
* NOTE: MAKE SURE THE ASTERISK IS REMOVED BEFORE THE WORD LIBNAME AND       *
*       MAKE SURE THAT THE GREATER THAN AND LESS THAN SIGNS < > ARE REMOVED *
*       FROM THE LIBNAME STATEMENT                                          *
*****************************************************************************;

*FILENAME FORMATIN '<PATH OF FORMAT ASSIGNMENT STATEMENT>' ;
*****************************************************************************
* EXAMPLE:                                                                  *
*          FILENAME FORMATIN 'C:\FORMATSTATEMENT.SAS'                       *
* NOTE: MAKE SURE THE ASTERISK IS REMOVED BEFORE THE WORD FILENAME AND      *
*       MAKE SURE THAT THE GREATER THAN AND LESS THAN SIGNS < > ARE REMOVED *
*       FROM THE FILENAME STATEMENT                                         *
*****************************************************************************;

DATA DATAOUT.SASDATA ;
INFILE DATAIN MISSOVER ;
INPUT
_STATE        1-2                     /* Record Identification */
FMONTH        17-18
IDATE         $19-26
IMONTH        $19-20
IDAY          $21-22
IYEAR         $23-26
DISPCODE      32-35
SEQNO         $36-45
_PSU          36-45
CTELENM1      63                      /* Land Line Introduction */
PVTRESD1      64
COLGHOUS      65
STATERE1      66
CELPHON1      67
LADULT1       68
COLGSEX       69
NUMADULT      70-71
LANDSEX       72
NUMMEN        73-74
NUMWOMEN      75-76
RESPSLCT      77
SAFETIME      78                      /* Cell Phone Introduction */
CTELNUM1      79
CELLFON5      80
CADULT1       81
CELLSEX       82
PVTRESD3      83
CCLGHOUS      84
CSTATE1       85
LANDLINE      88
HHADULT       89-90
SEXVAR        91                      /* Respondent Sex */
GENHLTH       101                     /* Section 1: Health Status */
PHYSHLTH      102-103                 /* Section 2: Healthy Days */
MENTHLTH      104-105
POORHLTH      106-107
PRIMINSR      108-109                 /* Section 3: Health Care Access */
PERSDOC3      110
MEDCOST1      111
CHECKUP1      112
EXERANY2      113                     /* Section 4: Exercise */
BPHIGH6       114                     /* Section 5: Hypertension Awareness */
BPMEDS        115
CHOLCHK3      116                     /* Section 6: Cholesterol Awareness */
TOLDHI3       117
CHOLMED3      118
CVDINFR4      119                     /* Section 7: Chronic Health Conditions */
CVDCRHD4      120
CVDSTRK3      121
ASTHMA3       122
ASTHNOW       123
CHCSCNCR      124
CHCOCNCR      125
CHCCOPD3      126
ADDEPEV3      127
CHCKDNY2      128
DIABETE4      129
DIABAGE3      130-131
HAVARTH5      132                     /* Section 8: Arthritis */
ARTHEXER      133
ARTHEDU       134
LMTJOIN3      135
ARTHDIS2      136
JOINPAI2      137-138
MARITAL       175
EDUCA         176
RENTHOM1      177
NUMHHOL3      186
NUMPHON3      187
CPDEMO1B      188
VETERAN3      189
EMPLOY1       190
CHILDREN      191-192
INCOME3       193-194
PREGNANT      195
WEIGHT2       196-199
HEIGHT3       200-203
DEAF          204                     /* Section 10: Disability */
BLIND         205
DECIDE        206
DIFFWALK      207
DIFFDRES      208
DIFFALON      209
SMOKE100      210                     /* Section 11: Tobacco Use */
SMOKDAY2      211
USENOW3       212
ECIGNOW1      213
ALCDAY5       214-216                 /* Section 12: Alcohol Consumption */
AVEDRNK3      217-218
DRNK3GE5      219-220
MAXDRNKS      221-222
FLUSHOT7      223                     /* Section 13: Immunization */
FLSHTMY3      224-229
IMFVPLA2      230-231
PNEUVAC4      232
HIVTST7       233                     /* Section 14: HIV/AIDS */
HIVTSTD3      234-239
FRUIT2        240-242                 /* Section 15: Fruits & Vegetables */
FRUITJU2      243-245
FVGREEN1      246-248
FRENCHF1      249-251
POTATOE1      252-254
VEGETAB2      255-257
PDIABTST      258                     /* Module 1: Pre-Diabetes */
PREDIAB1      259
INSULIN1      260                     /* Module 2: Diabetes */
BLDSUGAR      261-263
FEETCHK3      264-266
DOCTDIAB      267-268
CHKHEMO3      269-270
FEETCHK       271-272
EYEEXAM1      273
DIABEYE       274
DIABEDU       275
TOLDCFS       276                     /* Module 3: ME/CFS */
HAVECFS       277
WORKCFS       278
TOLDHEPC      279                     /* Module 4: Hepatitis Treatment */
TRETHEPC      280
PRIRHEPC      281
HAVEHEPC      282
HAVEHEPB      283
MEDSHEPB      284
HPVADVC4      285                     /* Module 5: HPV Vaccination */
HPVADSHT      286-287
TETANUS1      288                     /* Module 6: Tetanus Diphtheria (Tdap) (Adults) */
SHINGLE2      289                     /* Module 7: Shingles Vaccination */
LCSFIRST      308-310                 /* Module 9: Lung Cancer Screening */
LCSLAST       311-313
LCSNUMCG      314-316
LCSCTSCN      317
HADMAM        318                     /* Module 10: Breast and Cervical Cancer Screening */
HOWLONG       319
CERVSCRN      320
CRVCLCNC      321
CRVCLPAP      322
CRVCLHPV      323
HADHYST2      324
PSATEST1      325                     /* Module 11: Prostate Cancer Screening */
PSATIME1      326
PCPSARS2      327
PCSTALK       328
HADSIGM4      329                     /* Module 12: Colorectal Cancer Screening */
COLNSIGM      330
COLNTES1      331
SIGMTES1      332
LASTSIG4      333
COLNCNCR      334
VIRCOLO1      335
VCLNTES1      336
SMALSTOL      337
STOLTEST      338
STOOLDN1      339
BLDSTFIT      340
SDNATES1      341
CNCRDIFF      342                     /* Module 13: Cancer Survivorship: Type of Cancer */
CNCRAGE       343-344
CNCRTYP1      345-346
CSRVTRT3      347                     /* Module 14: Cancer Survivorship: Course of Treatment */
CSRVDOC1      348-349
CSRVSUM       350
CSRVRTRN      351
CSRVINST      352
CSRVINSR      353
CSRVDEIN      354
CSRVCLIN      355
CSRVPAIN      356                     /* Module 15: Cancer Survivorship: Pain Management */
CSRVCTL2      357
HOMBPCHK      358                     /* Module 16: Home/ Self-measured Blood Pressure */
HOMRGCHK      359
WHEREBP       360
SHAREBP       361
WTCHSALT      362                     /* Module 17: Sodium or Salt-Related Behavior */
DRADVISE      363
CIMEMLOS      364                     /* Module 18: Cognitive Decline */
CDHOUSE       365
CDASSIST      366
CDHELP        367
CDSOCIAL      368
CDDISCUS      369
CAREGIV1      370                     /* Module 19: Caregiver */
CRGVREL4      371-372
CRGVLNG1      373
CRGVHRS1      374
CRGVPRB3      375-376
CRGVALZD      377
CRGVPER1      378
CRGVHOU1      379
CRGVEXPT      380
ACEDEPRS      381                     /* Module 20: Adverse Childhood Experiences */
ACEDRINK      382
ACEDRUGS      383
ACEPRISN      384
ACEDIVRC      385
ACEPUNCH      386
ACEHURT1      387
ACESWEAR      388
ACETOUCH      389
ACETTHEM      390
ACEHVSEX      391
ACEADSAF      392
ACEADNED      393
MARIJAN1      394-395                 /* Module 21: Marijuana Use */
USEMRJN3      396
RSNMRJN2      397
LASTSMK2      398-399                 /* Module 22: Tobacco Cessation */
STOPSMK2      400
FIREARM5      401                     /* Module 23: Firearm Safety */
GUNLOAD       402
LOADULK2      403
RCSGENDR      610
RCSRLTN2      645
CASTHDX2      646                     /* Module 26: Childhood Asthma Prevalence */
CASTHNO2      647
BIRTHSEX      648                     /* Module 27: Sex at Birth */
SOMALE        649
SOFEMALE      650
TRNSGNDR      651
QSTVER        656-657                 /* Questionnaire Version */
QSTLANG       658-659                 /* Questionnaire Language */
_METSTAT      1402
_URBSTAT      1403
MSCODE        1409
_STSTR        1410-1415
_STRWT        1416-1425
_RAWRAKE      1446-1455
_WT2RAKE      1456-1465
_IMPRACE      1471-1472
_CHISPNC      1482                    /* Child Demographic Variables */
_CRACE1       1539-1540
_CPRACE1      1541-1542
CAGEG         1569
_CLLCPWT      1585-1594
_DUALUSE      1682
_DUALCOR      1683-1692
_LLCPWT2      1693-1702
_LLCPWT       1751-1760
_RFHLTH       1899                    /* Section 1: Calculated Variables */
_PHYS14D      1900                    /* Section 2: Calculated Variables */
_MENT14D      1901
_HLTHPLN      1902                    /* Section 3: Calculated Variables */
_HCVU652      1903
_TOTINDA      1904                    /* Section 4: Calculated Variables */
_RFHYPE6      1905                    /* Section 5: Calculated Variables */
_CHOLCH3      1906                    /* Section 6: Calculated Variables */
_RFCHOL3      1907
_MICHD        1908                    /* Section 7: Calculated Variables */
_LTASTH1      1909
_CASTHM1      1910
_ASTHMS1      1911
_DRDXAR3      1912                    /* Section 8: Calculated Variables */
_LMTACT3      1913
_LMTWRK3      1914
_PRACE1       1971-1972
_MRACE1       1973-1974
_HISPANC      1977
_RACE         1978
_RACEG21      1979
_RACEGR3      1980
_RACEPRV      1981
_SEX          1982
_AGEG5YR      1983-1984
_AGE65YR      1985
_AGE80        1986-1987
_AGE_G        1988
HTIN4         1989-1991
HTM4          1992-1994
WTKG3         1995-1999
_BMI5         2000-2003
_BMI5CAT      2004
_RFBMI5       2005
_CHLDCNT      2006
_EDUCAG       2007
_INCOMG1      2008
_SMOKER3      2009                    /* Section 11: Calculated Variables */
_RFSMOK3      2010
_CURECI1      2011
DRNKANY5      2012                    /* Section 12: Calculated Variables */
DROCDY3_      2013-2015
_RFBING5      2016
_DRNKWK1      2017-2021
_RFDRHV7      2022
_FLSHOT7      2023                    /* Section 13: Calculated Variables */
_PNEUMO3      2024
_AIDTST4      2025                    /* Section 14: Calculated Variables */
FTJUDA2_      2026-2029               /* Section 15: Calculated Variables */
FRUTDA2_      2030-2033
GRENDA1_      2034-2037
FRNCHDA_      2038-2041
POTADA1_      2042-2045
VEGEDA2_      2046-2049
_MISFRT1      2050
_MISVEG1      2051
_FRTRES1      2052
_VEGRES1      2053
_FRUTSU1      2054-2059
_VEGESU1      2060-2065
_FRTLT1A      2066
_VEGLT1A      2067
_FRT16A       2068
_VEG23A       2069
_FRUITE1      2070
_VEGETE1      2071
;
*****************************************************************
* TO INCLUDE THE FORMAT ASSIGNEMT STATEMENT REMOVE THE ASTERISK *
* FROM THE BEGINNING OF THE FOLLOWING LINE                      *
*****************************************************************;
* %INCLUDE FORMATIN ;
*************************************************
* THIS SECTION CREATES LABELS FOR THE VARIABLES *
*************************************************;
Label
ACEADNED = 'DID AN ADULT MAKE SURE BASIC NEEDS WERE MET'
ACEADSAF = 'DID AN ADULT MAKE YOU FEEL SAFE AND PROTECTED'
ACEDEPRS = 'LIVE WITH ANYONE DEPRESSED, MENTALLY ILL, OR SUICIDAL?'
ACEDIVRC = 'WERE YOUR PARENTS DIVORCED/SEPERATED?'
ACEDRINK = 'LIVE WITH A PROBLEM DRINKER/ALCOHOLIC?'
ACEDRUGS = 'LIVE WITH ANYONE WHO USED ILLEGAL DRUGS OR ABUSED PRESCRIPTIONS?'
ACEHURT1 = 'HOW OFTEN DID A PARENT PHYSICALLY HURT YOU IN ANY WAY?'
ACEHVSEX = 'HOW OFTEN DID ANYONE EVER FORCE YOU TO HAVE SEX?'
ACEPRISN = 'LIVE WITH ANYONE WHO SERVED TIME IN PRISON OR JAIL?'
ACEPUNCH = 'HOW OFTEN DID YOUR PARENTS BEAT EACH OTHER UP?'
ACESWEAR = 'HOW OFTEN DID A PARENT SWEAR AT YOU?'
ACETOUCH = 'HOW OFTEN DID ANYONE EVER TOUCH YOU SEXUALLY?'
ACETTHEM = 'HOW OFTEN DID ANYONE MAKE YOU TOUCH THEM SEXUALLY?'
ADDEPEV3 = '(EVER TOLD) YOU HAD A DEPRESSIVE DISORDER'
ALCDAY5 = 'DAYS IN PAST 30 HAD ALCOHOLIC BEVERAGE'
ARTHDIS2 = 'DOES ARTHRITIS AFFECT WHETHER YOU WORK'
ARTHEDU = 'EVER TAKEN CLASS IN MANAGING ARTHRITIS OR JOINT SYMPTOMS'
ARTHEXER = 'DR. SUGGEST USE OF PHYSICAL ACTIVITY OR EXERCISE FOR ARTHRITIS OR JOINT SYMPTOMS'
ASTHMA3 = 'EVER TOLD HAD ASTHMA'
ASTHNOW = 'STILL HAVE ASTHMA'
AVEDRNK3 = 'AVG ALCOHOLIC DRINKS PER DAY IN PAST 30'
BIRTHSEX = 'ARE YOU MALE OR FEMALE?'
BLDSTFIT = 'WAS TEST PART OF COLOGUARD TEST?'
BLDSUGAR = 'HOW OFTEN CHECK BLOOD FOR GLUCOSE'
BLIND = 'BLIND OR DIFFICULTY SEEING'
BPHIGH6 = 'EVER TOLD BLOOD PRESSURE HIGH'
BPMEDS = 'CURRENTLY TAKING BLOOD PRESSURE MEDICATION'
CADULT1 = 'ARE YOU 18 YEARS OF AGE OR OLDER?'
CAGEG = 'FOUR LEVEL CHILD AGE'
CAREGIV1 = 'PROVIDED REGULAR CARE FOR FAMILY OR FRIEND'
CASTHDX2 = 'HLTH PRO EVER SAID CHILD HAS ASTHMA'
CASTHNO2 = 'CHILD STILL HAVE ASTHMA?'
CCLGHOUS = 'DO YOU LIVE IN COLLEGE HOUSING?'
CDASSIST = 'NEED ASSISTANCE WITH DAY-TO_DAY ACTIVITIES DUE TO CONFUSION OR MEMORY LOSS'
CDDISCUS = 'HAVE YOU DISCUSSED YOUR CONFUSION OR MEMORY LOSS WITH A HEALTH CARE PROFESSIONAL?'
CDHELP = 'WHEN YOU NEED HELP WITH DAY-TO-DAY ACTIVITIES ARE YOU ABLE TO GET IT'
CDHOUSE = 'GIVEN UP DAY-TO-DAY CHORES DUE TO CONFUSION OR MEMORY LOSS'
CDSOCIAL = 'DOES CONFUSION OR MEMORY LOSS INTERFERE WITH WORK OR SOCIAL ACTIVITIES'
CELLFON5 = 'IS THIS A CELL PHONE?'
CELLSEX = 'ARE YOU MALE OR FEMALE?'
CELPHON1 = 'CELLULAR TELEPHONE'
CERVSCRN = 'HAVE YOU EVER HAD A CERVICAL CANCER SCREENING TEST?'
CHCCOPD3 = 'EVER TOLD YOU HAD C.O.P.D. EMPHYSEMA OR CHRONIC BRONCHITIS?'
CHCKDNY2 = 'EVER TOLD YOU HAVE KIDNEY DISEASE?'
CHCOCNCR = '(EVER TOLD) YOU HAD ANY OTHER TYPES OF CANCER?'
CHCSCNCR = '(EVER TOLD) YOU HAD SKIN CANCER?'
CHECKUP1 = 'LENGTH OF TIME SINCE LAST ROUTINE CHECKUP'
CHILDREN = 'NUMBER OF CHILDREN IN HOUSEHOLD'
CHKHEMO3 = 'TIMES CHECKED FOR GLYCOSYLATED HEMOGLOBIN'
CHOLCHK3 = 'HOW LONG SINCE CHOLESTEROL CHECKED'
CHOLMED3 = 'CURRENTLY TAKING MEDICINE FOR HIGH CHOLESTEROL'
CIMEMLOS = 'HAVE YOU EXPERIENCED CONFUSION OR MEMORY LOSS THAT IS HAPPENING MORE OFTEN OR IS GETTING WORSE?'
CNCRAGE = 'AGE TOLD HAD CANCER'
CNCRDIFF = 'HOW MANY TYPES OF CANCER?'
CNCRTYP1 = 'TYPE OF CANCER'
COLGHOUS = 'DO YOU LIVE IN COLLEGE HOUSING?'
COLGSEX = 'ARE YOU MALE OR FEMALE?'
COLNCNCR = 'EVER HAD ANY OTHER KIND OF TEST FOR COLORECTAL CANCER'
COLNSIGM = 'EVER HAD A COLONOSCOPY, SIGMOIDOSCOPY, OR BOTH'
COLNTES1 = 'HOW LONG HAS IT BEEN SINCE YOU HAD COLONOSCOPY?'
CPDEMO1B = 'DO YOU HAVE A CELL PHONE FOR PERSONAL USE?'
CRGVALZD = 'DOES PERSON BEING CARED FOR HAVE ALZHEIMERS DISEASE?'
CRGVEXPT = 'DO YOU EXPECT TO HAVE A RELATIVE YOU WILL NEED TO PROVIDE CARE FOR?'
CRGVHOU1 = 'MANAGED HOUSEHOLD TASKS'
CRGVHRS1 = 'HOW MANY HOURS DO YOU PROVIDE CARE FOR PERSON?'
CRGVLNG1 = 'HOW LONG PROVIDED CARE FOR PERSON.'
CRGVPER1 = 'MANAGED PERSONAL CARE'
CRGVPRB3 = 'WHAT IS THE MAJOR HEALTH PROBLEM, ILLNESS, DISABILITY FOR CARE FOR PERSON?'
CRGVREL4 = 'RELATIONSHIP OF PERSON TO WHOM YOU ARE GIVING CARE?'
CRVCLCNC = 'TIME SINCE LAST CERVICAL CANCER SCREENING TEST'
CRVCLHPV = 'HAVE AN H.P.V. TEST AND RECENT CERVICAL CANCER SCREENING'
CRVCLPAP = 'HAVE A PAP TEST AND RECENT CERVICAL CANCER SCREENING'
CSRVCLIN = 'PARTICIPATE IN CLINICAL TRIAL AS PART OF CANCER TREATMENT?'
CSRVCTL2 = 'IS PAIN UNDER CONTROL?'
CSRVDEIN = 'EVER DENIED INSURANCE COVERAGE BECAUSE OF YOUR CANCER?'
CSRVDOC1 = 'WHAT TYPE OF DOCTOR PROVIDES MAJORITY OF YOUR CARE'
CSRVINSR = 'DID HEALTH INSURANCE PAY FOR ALL OF YOUR CANCER TREATMENT'
CSRVINST = 'INSTRUCTIONS WRITTEN OR PRINTED'
CSRVPAIN = 'CURRENTLY HAVE PHYSICAL PAIN FROM CANCER OR TREATMENT?'
CSRVRTRN = 'EVER RECEIVE INSTRUCTIONS FROM A DOCTOR FOR FOLLOW-UP CHECK-UPS'
CSRVSUM = 'DID YOU RECEIVE A SUMMARY OF CANCER TREATMENTS RECEIVED'
CSRVTRT3 = 'CURRENTLY RECEIVING TREATMENT FOR CANCER'
CSTATE1 = 'DO YOU CURRENTLY LIVE IN  ____(STATE)____?'
CTELENM1 = 'CORRECT TELEPHONE NUMBER?'
CTELNUM1 = 'CORRECT PHONE NUMBER?'
CVDCRHD4 = 'EVER DIAGNOSED WITH ANGINA OR CORONARY HEART DISEASE'
CVDINFR4 = 'EVER DIAGNOSED WITH HEART ATTACK'
CVDSTRK3 = 'EVER DIAGNOSED WITH A STROKE'
DEAF = 'ARE YOU DEAF OR DO YOU HAVE SERIOUS DIFFICULTY HEARING?'
DECIDE = 'DIFFICULTY CONCENTRATING OR REMEMBERING'
DIABAGE3 = 'AGE WHEN TOLD DIABETES'
DIABEDU = 'EVER TAKEN CLASS IN MANAGING DIABETES'
DIABETE4 = '(EVER TOLD) YOU HAD DIABETES'
DIABEYE = 'EVER TOLD DIABETES HAS AFFECTED EYES'
DIFFALON = 'DIFFICULTY DOING ERRANDS ALONE'
DIFFDRES = 'DIFFICULTY DRESSING OR BATHING'
DIFFWALK = 'DIFFICULTY WALKING OR CLIMBING STAIRS'
DISPCODE = 'FINAL DISPOSITION'
DOCTDIAB = 'TIMES SEEN HEALTH PROFESSIONAL FOR DIABETES'
DRADVISE = 'DOCTOR ADVISED REDUCED SODIUM/SALT INTAKE'
DRNK3GE5 = 'BINGE DRINKING'
DRNKANY5 = 'DRINK ANY ALCOHOLIC BEVERAGES IN PAST 30 DAYS'
DROCDY3_ = 'COMPUTED DRINK-OCCASIONS-PER-DAY'
ECIGNOW1 = 'DO YOU NOW USE E-CIGARETTES, EVERY DAY, SOME DAYS, OR NOT AT ALL?'
EDUCA = 'EDUCATION LEVEL'
EMPLOY1 = 'EMPLOYMENT STATUS'
EXERANY2 = 'EXERCISE IN PAST 30 DAYS'
EYEEXAM1 = 'LAST EYE EXAM WHERE PUPILS WERE DILATED'
FEETCHK = 'TIMES FEET CHECK FOR SORES/IRRITATIONS'
FEETCHK3 = 'HOW OFTEN CHECK FEET FOR SORES OR IRRITATIONS'
FIREARM5 = 'ANY FIREARMS IN HOME'
FLSHTMY3 = 'WHEN RECEIVED MOST RECENT SEASONAL FLU SHOT/SPRAY'
FLUSHOT7 = 'ADULT FLU SHOT/SPRAY PAST 12 MOS'
FMONTH = 'FILE MONTH'
FRENCHF1 = 'HOW OFTEN DO YOU EAT FRENCH FRIES OR FRIED POTATOES?'
FRNCHDA_ = 'FRENCH FRY INTAKE IN TIMES PER DAY'
FRUIT2 = 'HOW MANY TIMES DID YOU EAT FRUIT?'
FRUITJU2 = 'HOW MANY TIMES DID YOU DRINK 100 PERCENT PURE FRUIT JUICES?'
FRUTDA2_ = 'COMPUTED FRUIT INTAKE IN TIMES PER DAY'
FTJUDA2_ = 'COMPUTED FRUIT JUICE INTAKE IN TIMES PER DAY'
FVGREEN1 = 'HOW MANY TIMES DID YOU EAT DARK GREEN VEGETABLES?'
GENHLTH = 'GENERAL HEALTH'
GRENDA1_ = 'COMPUTED DARK GREEN VEGETABLE INTAKE IN TIMES PER DAY'
GUNLOAD = 'ANY FIREARMS LOADED'
HADHYST2 = 'HAD HYSTERECTOMY'
HADMAM = 'HAVE YOU EVER HAD A MAMMOGRAM'
HADSIGM4 = 'EVER HAD SIGMOIDOSCOPY/COLONOSCOPY'
HAVARTH5 = 'TOLD HAVE ARTHRITIS'
HAVECFS = 'STILL HAVE CHRONIC FATIGUE SYNDROME OR MYALGIC ENCEPHALOMYELITIS'
HAVEHEPB = 'TOLD  HAD HEPATITIS B'
HAVEHEPC = 'STILL HAVE HEPATITIS C'
HEIGHT3 = 'REPORTED HEIGHT IN FEET AND INCHES'
HHADULT = 'NUMBER OF ADULTS IN HOUSEHOLD'
HIVTST7 = 'EVER TESTED H.I.V.'
HIVTSTD3 = 'MONTH AND YEAR OF LAST HIV TEST'
HOMBPCHK = 'TOLD CHECK BLOOD PRESSURE AT HOME'
HOMRGCHK = 'REGULARLY CHECK BLOOD PRESSURE AT HOME'
HOWLONG = 'HOW LONG SINCE LAST MAMMOGRAM'
HPVADSHT = 'NUMBER OF HPV SHOTS RECEIVED'
HPVADVC4 = 'EVER HAD AN H.P.V. VACCINATION?'
HTIN4 = 'COMPUTED HEIGHT IN INCHES'
HTM4 = 'COMPUTED HEIGHT IN METERS'
IDATE = 'INTERVIEW DATE'
IDAY = 'INTERVIEW DAY'
IMFVPLA2 = 'WHERE DID YOU GET YOUR LAST FLU SHOT/VACCINE?'
IMONTH = 'INTERVIEW MONTH'
INCOME3 = 'INCOME LEVEL'
INSULIN1 = 'NOW TAKING INSULIN'
IYEAR = 'INTERVIEW YEAR'
JOINPAI2 = 'HOW BAD WAS JOINT PAIN'
LADULT1 = 'ARE YOU 18 YEARS OF AGE OR OLDER?'
LANDLINE = 'DO YOU ALSO HAVE A LANDLINE TELEPHONE?'
LANDSEX = 'ARE YOU MALE OR FEMALE?'
LASTSIG4 = 'TIME SINCE LAST SIGMOIDOSCOPY/COLONOSCOPY'
LASTSMK2 = 'INTERVAL SINCE LAST SMOKED'
LCSCTSCN = 'DID YOU HAVE A CT OR CAT SCAN?'
LCSFIRST = 'HOW OLD WHEN YOU FIRST STARTED SMOKING?'
LCSLAST = 'HOW OLD WHEN YOU LAST SMOKED?'
LCSNUMCG = 'ON AVERAGE, HOW MANY CIGARETTES DO YOU SMOKE EACH DAY?'
LMTJOIN3 = 'LIMITED BECAUSE OF JOINT SYMPTOMS'
LOADULK2 = 'ANY LOADED FIREARMS ALSO UNLOCKED'
MARIJAN1 = 'DURING THE PAST 30 DAYS, ON HOW MANY DAYS DID YOU USE MARIJUANA OR HASHISH?'
MARITAL = 'MARITAL STATUS'
MAXDRNKS = 'MOST DRINKS ON SINGLE OCCASION PAST 30 DAYS'
MEDCOST1 = 'COULD NOT AFFORD TO SEE DOCTOR'
MEDSHEPB = 'CURRENTLY TAKING MEDICINE FOR HEPATITIS B'
MENTHLTH = 'NUMBER OF DAYS MENTAL HEALTH NOT GOOD'
MSCODE = 'METROPOLITAN STATUS CODE'
NUMADULT = 'NUMBER OF ADULTS IN HOUSEHOLD'
NUMHHOL3 = 'HOUSEHOLD TELEPHONES'
NUMMEN = 'NUMBER OF ADULT MEN IN HOUSEHOLD'
NUMPHON3 = 'RESIDENTIAL PHONES'
NUMWOMEN = 'NUMBER OF ADULT WOMEN IN HOUSEHOLD'
PCPSARS2 = 'WHAT WAS THE MAIN REASON YOU HAD THIS PSA TEST?'
PCSTALK = 'DID YOU TALK ABOUT THE ADVANTAGES OR DISADVANTAGES OF P.S.A. TEST'
PDIABTST = 'HAD A TEST FOR HIGH BLOOD SUGAR IN PAST THREE YEARS'
PERSDOC3 = 'HAVE PERSONAL HEALTH CARE PROVIDER?'
PHYSHLTH = 'NUMBER OF DAYS PHYSICAL HEALTH NOT GOOD'
PNEUVAC4 = 'PNEUMONIA SHOT EVER'
POORHLTH = 'POOR PHYSICAL OR MENTAL HEALTH'
POTADA1_ = 'COMPUTED POTATO SERVINGS PER DAY'
POTATOE1 = 'HOW OFTEN DO YOU EAT FRENCH FRIES OR FRIED POTATOES?'
PREDIAB1 = 'EVER BEEN TOLD YOU HAVE PRE-DIABETES OR BORDERLINE DIABETES'
PREGNANT = 'PREGNANCY STATUS'
PRIMINSR = 'WHAT IS PRIMARY SOURCE OF HEALTH INSURANCE?'
PRIRHEPC = 'WERE YOU TREATED FOR HEPATITIS C PRIOR TO 2015'
PSATEST1 = 'EVER HAD PSA TEST'
PSATIME1 = 'TIME SINCE MOST RECENT PSA TEST'
PVTRESD1 = 'PRIVATE RESIDENCE?'
PVTRESD3 = 'DO YOU LIVE IN A PRIVATE RESIDENCE?'
QSTLANG = 'LANGUAGE IDENTIFIER'
QSTVER = 'QUESTIONNAIRE VERSION IDENTIFIER'
RCSGENDR = 'GENDER OF CHILD'
RCSRLTN2 = 'RELATIONSHIP TO CHILD'
RENTHOM1 = 'OWN OR RENT HOME'
RESPSLCT = 'RESPONDENT SELECTION'
RSNMRJN2 = 'WHAT WAS THE REASON YOU USED MARIJUANA?'
SAFETIME = 'SAFE TIME TO TALK?'
SDNATES1 = 'HOW LONG SINCE YOU HAD STOOL DNA?'
SEQNO = 'ANNUAL SEQUENCE NUMBER'
SEXVAR = 'SEX OF RESPONDENT'
SHAREBP = 'HOW DO YOU SHARE YOUR BLOOD PRESSURE NUMBERS'
SHINGLE2 = 'HAVE YOU EVER HAD THE SHINGLES OR ZOSTER VACCINE?'
SIGMTES1 = 'HOW LONG HAS IT BEEN SINCE YOU HAD SIGMOIDOSCOPY?'
SMALSTOL = 'EVER HAD STOOL TEST?'
SMOKDAY2 = 'FREQUENCY OF DAYS NOW SMOKING'
SMOKE100 = 'SMOKED AT LEAST 100 CIGARETTES'
SOFEMALE = 'SEXUAL ORIENTATION'
SOMALE = 'SEXUAL ORIENTATION'
STATERE1 = 'RESIDENT OF STATE'
STOLTEST = 'HOW LONG SINCE YOU HAD STOOL TEST?'
STOOLDN1 = 'EVER HAD STOOL DNA TEST?'
STOPSMK2 = 'STOPPED SMOKING IN PAST 12 MONTHS'
TETANUS1 = 'RECEIVED TETANUS SHOT SINCE 2005?'
TOLDCFS = 'TOLD HAD CHRONIC FATIGUE SYNDROME OR MYALGIC ENCEPHALOMYELITIS'
TOLDHEPC = 'TOLD HAD HEPATITIS C'
TOLDHI3 = 'EVER TOLD CHOLESTEROL IS HIGH'
TRETHEPC = 'TREATED FOR HEPATITIS C'
TRNSGNDR = 'DO YOU CONSIDER YOURSELF TO BE TRANSGENDER?'
USEMRJN3 = 'DURING THE PAST 30 DAYS, HOW DID YOU PRIMARILY USE MARIJUANA?'
USENOW3 = 'USE OF SMOKELESS TOBACCO PRODUCTS'
VCLNTES1 = 'HOW LONG HAS IT BEEN SINCE YOU HAD VIRTUAL COLONOSCOPY?'
VEGEDA2_ = 'COMPUTED OTHER VEGETABLE INTAKE IN TIMES PER  DAY'
VEGETAB2 = 'HOW OFTEN DO YOU EAT FRENCH FRIES OR FRIED POTATOES?'
VETERAN3 = 'ARE YOU A VETERAN'
VIRCOLO1 = 'HAVE YOU EVER HAD A VIRTUAL COLONOSCOPY?'
WEIGHT2 = 'REPORTED WEIGHT IN POUNDS'
WHEREBP = 'WHERE DO YOU GET BLOOD PRESSURE TAKEN'
WORKCFS = 'HOW MANY HOURS A WEEK ARE YOU BEEN ABLE TO WORK'
WTCHSALT = 'WATCHING SODIUM OR SALT INTAKE'
WTKG3 = 'COMPUTED WEIGHT IN KILOGRAMS'
_AGE65YR = 'REPORTED AGE IN TWO AGE GROUPS CALCULATED VARIABLE'
_AGE80 = 'IMPUTED AGE VALUE COLLAPSED ABOVE 80'
_AGEG5YR = 'REPORTED AGE IN FIVE-YEAR AGE CATEGORIES CALCULATED VARIABLE'
_AGE_G = 'IMPUTED AGE IN SIX GROUPS'
_AIDTST4 = 'EVER BEEN TESTED FOR HIV CALCULATED VARIABLE'
_ASTHMS1 = 'COMPUTED ASTHMA STATUS'
_BMI5 = 'COMPUTED BODY MASS INDEX'
_BMI5CAT = 'COMPUTED BODY MASS INDEX CATEGORIES'
_CASTHM1 = 'CURRENT ASTHMA CALCULATED VARIABLE'
_CHISPNC = 'CHILD HISPANIC, LATINO/A, OR SPANISH ORIGIN CALCULATED VARIABLE'
_CHLDCNT = 'COMPUTED NUMBER OF CHILDREN IN HOUSEHOLD'
_CHOLCH3 = 'CHOLESTEROL CHECKED CALCULATED VARIABLE'
_CLLCPWT = 'FINAL CHILD WEIGHT: LAND-LINE AND CELL-PHONE DATA'
_CPRACE1 = 'PREFERRED CHILD RACE CATEGORIES'
_CRACE1 = 'CHILD NON-HISPANIC RACE INCLUDING MULTIRACIAL'
_CURECI1 = 'CURRENT E-CIGARETTE USER CALCULATED VARIABLE'
_DRDXAR3 = 'RESPONDENTS DIAGNOSED WITH ARTHRITIS'
_DRNKWK1 = 'COMPUTED NUMBER OF DRINKS OF ALCOHOL BEVERAGES PER WEEK'
_DUALCOR = 'DUAL PHONE USE CORRECTION FACTOR'
_DUALUSE = 'DUAL PHONE USE CATEGORIES'
_EDUCAG = 'COMPUTED LEVEL OF EDUCATION COMPLETED CATEGORIES'
_FLSHOT7 = 'FLU SHOT CALCULATED VARIABLE'
_FRT16A = 'REPORTED CONSUMING FRUIT >16/DAY'
_FRTLT1A = 'CONSUME FRUIT 1 OR MORE TIMES PER DAY'
_FRTRES1 = 'MISSING ANY FRUIT RESPONSES'
_FRUITE1 = 'FRUIT EXCLUSION FROM ANALYSES'
_FRUTSU1 = 'TOTAL FRUITS CONSUMED PER DAY'
_HCVU652 = 'RESPONDENTS AGED 18-64 WITH HEALTH INSURANCE'
_HISPANC = 'HISPANIC, LATINO/A, OR SPANISH ORIGIN CALCULATED VARIABLE'
_HLTHPLN = 'HAVE ANY HEALTH INSURANCE'
_IMPRACE = 'IMPUTED RACE/ETHNICITY VALUE'
_INCOMG1 = 'COMPUTED INCOME CATEGORIES'
_LLCPWT = 'FINAL WEIGHT: LAND-LINE AND CELL-PHONE DATA'
_LLCPWT2 = 'TRUNCATED DESIGN WEIGHT USED IN ADULT COMBINED LAN  LINE AND CELL PHONE RAKING'
_LMTACT3 = 'LIMITED USUAL ACTIVITIES'
_LMTWRK3 = 'LIMITED WORK ACTIVITIES'
_LTASTH1 = 'LIFETIME ASTHMA CALCULATED VARIABLE'
_MENT14D = 'COMPUTED MENTAL HEALTH STATUS'
_METSTAT = 'METROPOLITAN STATUS'
_MICHD = 'RESPONDENTS THAT HAVE EVER REPORTED HAVING CORONARY HEART DISEASE (CHD) OR MYOCARDIAL INFARCTION (MI)'
_MISFRT1 = 'THE NUMBER OF MISSING FRUIT RESPONSES'
_MISVEG1 = 'THE NUMBER OF MISSING VEGETABLE RESPONSES'
_MRACE1 = 'CALCULATED NON-HISPANIC RACE INCLUDING MULTIRACIAL'
_PHYS14D = 'COMPUTED PHYSICAL HEALTH STATUS'
_PNEUMO3 = 'PNEUMONIA VACCINATION CALCULATED VARIABLE'
_PRACE1 = 'COMPUTED PREFERRED RACE'
_PSU = 'PRIMARY SAMPLING UNIT'
_RACE = 'COMPUTED RACE-ETHNICITY GROUPING'
_RACEG21 = 'COMPUTED NON-HISPANIC WHITES/ALL OTHERS RACE CATEGORIES RACE/ETHNIC GROUP CODES USED IN POST-STRATIFICATION.'
_RACEGR3 = 'COMPUTED FIVE LEVEL RACE/ETHNICITY CATEGORY.'
_RACEPRV = 'COMPUTED RACE GROUPS USED FOR INTERNET PREVALENCE TABLES'
_RAWRAKE = 'RAW WEIGHTING FACTOR USED IN RAKING'
_RFBING5 = 'BINGE DRINKING CALCULATED VARIABLE'
_RFBMI5 = 'OVERWEIGHT OR OBESE CALCULATED VARIABLE'
_RFCHOL3 = 'HIGH CHOLESTEROL CALCULATED VARIABLE'
_RFDRHV7 = 'HEAVY ALCOHOL CONSUMPTION  CALCULATED VARIABLE'
_RFHLTH = 'ADULTS WITH GOOD OR BETTER HEALTH'
_RFHYPE6 = 'HIGH BLOOD PRESSURE CALCULATED VARIABLE'
_RFSMOK3 = 'CURRENT SMOKING CALCULATED VARIABLE'
_SEX = 'CALCULATED SEX VARIABLE'
_SMOKER3 = 'COMPUTED SMOKING STATUS'
_STATE = 'STATE FIPS CODE'
_STRWT = 'STRATUM WEIGHT'
_STSTR = 'SAMPLE DESIGN STRATIFICATION VARIABLE'
_TOTINDA = 'LEISURE TIME PHYSICAL ACTIVITY CALCULATED VARIABLE'
_URBSTAT = 'URBAN/RURAL STATUS'
_VEG23A = 'REPORTED CONSUMING VEGETABLES >23/DAY'
_VEGESU1 = 'TOTAL VEGETABLES CONSUMED PER DAY'
_VEGETE1 = 'VEGETABLE EXCLUSION FROM ANALYSES'
_VEGLT1A = 'CONSUME VEGETABLES 1 OR MORE TIMES PER DAY'
_VEGRES1 = 'MISSING ANY VEGETABLE RESPONSES'
_WT2RAKE = 'DESIGN WEIGHT USED IN RAKING'
;
RUN;
